SocketAddr

Struct SocketAddr 

1.10.0 · Source
pub struct SocketAddr { /* private fields */ }
Available on Unix only.
An address associated with a Unix socket.

Examples

use std::os::unix::net::UnixListener;

let socket = match UnixListener::bind("/tmp/sock") {
    Ok(sock) => sock,
    Err(e) => {
        println!("Couldn't bind: {e:?}");
        return
    }
};
let addr = socket.local_addr().expect("Couldn't get local address");

Implementations

Source

impl SocketAddr

1.61.0 · Source

pub fn from_pathname<P>(path: P) -> Result<SocketAddr>
where P: AsRef<Path>,

Constructs a SockAddr with the family AF_UNIX and the provided path.

Errors

Returns an error if the path is longer than SUN_LEN or if it contains NULL bytes.

Examples
use std::os::unix::net::SocketAddr;
use std::path::Path;

let address = SocketAddr::from_pathname("/path/to/socket")?;
assert_eq!(address.as_pathname(), Some(Path::new("/path/to/socket")));

Creating a SocketAddr with a NULL byte results in an error.

use std::os::unix::net::SocketAddr;

assert!(SocketAddr::from_pathname("/path/with/\0/bytes").is_err());
1.10.0 · Source

pub fn is_unnamed(&self) -> bool

Returns true if the address is unnamed.

Examples

A named address:

use std::os::unix::net::UnixListener;

fn main() -> std::io::Result<()> {
    let socket = UnixListener::bind("/tmp/sock")?;
    let addr = socket.local_addr().expect("Couldn't get local address");
    assert_eq!(addr.is_unnamed(), false);
    Ok(())
}

An unnamed address:

use std::os::unix::net::UnixDatagram;

fn main() -> std::io::Result<()> {
    let socket = UnixDatagram::unbound()?;
    let addr = socket.local_addr().expect("Couldn't get local address");
    assert_eq!(addr.is_unnamed(), true);
    Ok(())
}
1.10.0 · Source

pub fn as_pathname(&self) -> Option<&Path>

Returns the contents of this address if it is a pathname address.

Examples

With a pathname:

use std::os::unix::net::UnixListener;
use std::path::Path;

fn main() -> std::io::Result<()> {
    let socket = UnixListener::bind("/tmp/sock")?;
    let addr = socket.local_addr().expect("Couldn't get local address");
    assert_eq!(addr.as_pathname(), Some(Path::new("/tmp/sock")));
    Ok(())
}

Without a pathname:

use std::os::unix::net::UnixDatagram;

fn main() -> std::io::Result<()> {
    let socket = UnixDatagram::unbound()?;
    let addr = socket.local_addr().expect("Couldn't get local address");
    assert_eq!(addr.as_pathname(), None);
    Ok(())
}